@@ -2,21 +2,22 @@ import sys
 import argparse
 import unittest
 import collections
+import pprint
 
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 
 class Error(Exception):
     pass
 
 
-def p(v):
-    print(v, file=sys.stderr)
-    return v
+def pp(x):
+    pprint.pprint(x, stream=sys.stderr)
+    return x
 
 
-def flatten(vs):
+def flatten(xss):
     """
     # Flatten containers
 
@@ -26,15 +27,15 @@ def flatten(vs):
     ## Exceptions
     - `RuntimeError`: Recursive elements will cause this
     """
-    if isinstance(vs, str):
-        yield vs
+    if isinstance(xss, str):
+        yield xss
     else:
-        for v in vs:
-            if isinstance(v, collections.abc.Iterable):
-                for v_ in flatten(v):
-                    yield v_
+        for xs in xss:
+            if isinstance(xs, collections.abc.Iterable):
+                for x in flatten(xs):
+                    yield x
             else:
-                yield v
+                yield xs
 
 
 def list_2d(n_row, n_column):
